class StatusChangeRequest:
    TYPE_CHANGE_STATUS_TO = "CHANGE_STATUS_TO"
    RELEASE = "RELEASE"
    OVERRIDE_SEASON_STATUS = "OVERRIDE_SEASON_STATUS"
    USE_SEASON_STATUS = "USE_SEASON_STATUS"

    def __init__(self, event_key, object_or_objects, status=None, hold_token=None, order_id=None, keep_extra_data=None, ignore_channels=None, channel_keys=None, allowed_previous_statuses=None, rejected_previous_statuses=None, type=None):
            self.type = type
            self.event_key = event_key
            self.object_or_objects = object_or_objects
            self.status = status
            self.hold_token = hold_token
            self.order_id = order_id
            self.keep_extra_data = keep_extra_data
            self.ignore_channels = ignore_channels
            self.channel_keys = channel_keys
            self.allowed_previous_statuses = allowed_previous_statuses
            self.rejected_previous_statuses = rejected_previous_statuses



class Page:

    def __init__(self, items, next_page_starts_after, previous_page_ends_before):
        self.next_page_starts_after = next_page_starts_after
        self.previous_page_ends_before = previous_page_ends_before
        self.items = items

    def set_next_page_starts_after(self, next_page_starts_after):
        self.next_page_starts_after = next_page_starts_after

    def set_previous_page_ends_before(self, previous_page_ends_before):
        self.previous_page_ends_before = previous_page_ends_before

    @classmethod
    def from_response(cls, response, clazz):
        next_page_starts_after = cls.get_value(response, "next_page_starts_after")
        previous_page_ends_before = cls.get_value(response, "previous_page_ends_before")
        items = cls.map_items(clazz, response)
        return Page(items, next_page_starts_after, previous_page_ends_before)

    @classmethod
    def get_value(cls, response, param_name):
        int_value = response.get(param_name, None)
        if int_value:
            int_value = int(int_value)
        return int_value

    @classmethod
    def map_items(cls, clazz, response):
        typed_items = []
        for item in response["items"]:
            typed_items.append(clazz(item))
        return typed_items



class ChannelProperties:
    def __init__(self, key=None, name=None, color=None, index=None, objects=None):
        if key is not None:
            self.key = key
        if name is not None:
            self.name = name
        if color is not None:
            self.color = color
        if index is not None:
            self.index = index
        if objects is not None:
            self.objects = objects



class ForSaleRequest:
    def __init__(self, objects, area_places, categories):
        if objects:
            self.objects = objects
        if area_places:
            self.areaPlaces = area_places
        if categories:
            self.categories = categories



class ReplaceChannelsRequest:
    def __init__(self, channels):
        if channels:
            self.channels = channels


class AssignObjectsToChannelsRequest:
    def __init__(self, channel_config):
        if channel_config:
            self.channelConfig = channel_config


class AddChannelRequest:
    def __init__(self, key, name, color, index, objects):
        self.key = key
        self.name = name
        self.color = color
        if index:
            self.index = index
        if objects:
            self.objects = objects


class EditObjectsForChannelRequest:
    def __init__(self, objects):
        self.objects = objects

class UpdateChannelRequest:
    def __init__(self, name, color, objects):
        if name:
            self.name = name
        if color:
            self.color = color
        if objects:
            self.objects = objects
